# cpl_media

A library providing kivy support for playing and recording from
various cameras.

For more information: https://matham.github.io/cpl_media/index.html

To install https://matham.github.io/cpl_media/installation.html
